
![](https://raw.githubusercontent.com/epykure/epyk-flask/master/epyk_flask/static/images/epyk-flask.png)

### First Version out now!

Web Server embedding the Epyk Python Framework to allow you to leverage on the power of HTML and JS all from python

Installation:
==================

pip install epyk_flask


Get Started:
==============

epyk-flask new -p server_path

This will create a new server structure at the path of your choice

epyk-flask env -p server_path/epyk_flask/UI/scripts

This will create a new environments where you want to store scripts that will use Epyk


Configuration:
=================

The configuration for your server is located under:

server_path/epyk_flask/config

Please be aware the epyk_flask is the name of your project by default but it can be different if you chose to create it with a different name



Documentation:
==================

Please refer to the documentation from the package Epyk to get started with your first pages.
